==> nextcloud-21.0.8p0.tgz: nextcloud/apps/password_policy/l10n/sc.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Sa crae est iscadida, imprea su mètodu de crae iscaressida pro torrare a impostare",
    "Password must not have been used recently before." : "Sa crae non depet èssere istada impreada pagu ora in antis",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Sa crae est in una lista de 1,000,000 de craes prus comunes. Faghe chi siat ùnica.",
    "Password is present in compromised password list. Please choose a different password." : "Sa crae est presente in una lista de craes cumprometidas. Sebera·nde un'àtera.",
    "Password needs to be at least %s characters long." : "Sa crae depet èssere longa a su mancu %s caràteres.",
    "Password needs to contain at least one numeric character." : "Sa crae depet cuntènnere a su mancu unu nùmeru.",
    "Password needs to contain at least one special character." : "Sa crae depet cuntènnere a su mancu unu caràtere ispetziale.",
    "Password needs to contain at least one lower and one upper case character." : "Sa crae depet cuntènnere unu caràtere a piticu e unu a mannu.",
    "Password policy" : "Normativa de is craes",
    "Allows admins to configure a password policy" : "Permitit a s'amministratzione de cunfigurare una normativa de is craes",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permiti a s'amministratzione de definire unas pre-cunditziones pro sa crae, comente pònnere una longària mìnima",
    "Saved" : "Sarvadu",
    "Minimum password length" : "Longària mìnima de crae",
    "User password history" : "Cronologia de is craes de s'utente",
    "Number of days until user password expires" : "Nùmeru de dies in antis de s'iscadèntzia de sa crae",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Nùmeru de tentativos de intrada in antis de su blocu de su contu (0 pro perunu lìmite)",
    "Forbid common passwords" : "Proibi is craes comunes",
    "Enforce upper and lower case characters" : "Pone caràteres a piticu e a mannu",
    "Enforce numeric characters" : "Pone caràtere numèricos",
    "Enforce special characters" : "Pone caràteres ispetziales",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Verìfica sa crae cun sa lista de craees cumprometidas de haveibeenpwnd.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Custu controllu creat unu hash de sa crae e imbiat is primu 5 caràteres de custu hash a is API de haveibeenpwned.com pro recuperare una lista de totu is hash chi cumintzant cun cussos caràteres. Luegu controllat si sa crae Nextcloud est presente in is resurtados.",
    "Unknown error" : "Errore disconnotu",
    "Minimal length has to be a non negative number" : "Sa longària mìnima depet èssere unu nùmeru positivu",
    "History size has to be a non negative number" : "Sa mannària de sa cronologia deper èssere unu nùmeru positivu",
    "Expiration days have to be a non negative number" : "Is dies de iscadèntzia depent èssere unu nùmeru positivu",
    "Maximum login attempts have to be a non negative number" : "Is tentativos de intrada màssimos depent èssere unu nùmeru positivu",
    "Password needs to be at least %s characters long" : "Sa crae depet èssere longa a su mancu %scaràteres "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.1.1.tgz: nextcloud/apps/password_policy/l10n/sc.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Sa crae est iscadida, imprea su mètodu de crae iscaressida pro torrare a impostare",
    "Password must not have been used recently before." : "Sa crae non depet èssere istada impreada pagu ora in antis",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Sa crae est in una lista de 1,000,000 de craes prus comunes. Faghe chi siat ùnica.",
    "Password is present in compromised password list. Please choose a different password." : "Sa crae est presente in una lista de craes cumprometidas. Sebera·nde un'àtera.",
    "Password needs to be at least %s characters long." : "Sa crae depet èssere longa a su mancu %s caràteres.",
    "Password needs to contain at least one numeric character." : "Sa crae depet cuntènnere a su mancu unu nùmeru.",
    "Password needs to contain at least one special character." : "Sa crae depet cuntènnere a su mancu unu caràtere ispetziale.",
    "Password needs to contain at least one lower and one upper case character." : "Sa crae depet cuntènnere unu caràtere a piticu e unu a mannu.",
    "Password policy" : "Normativa de is craes",
    "Allows admins to configure a password policy" : "Permitit a s'amministratzione de cunfigurare una normativa de is craes",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permiti a s'amministratzione de definire unas pre-cunditziones pro sa crae, comente pònnere una longària mìnima",
    "Saved" : "Sarvadu",
    "Minimum password length" : "Longària mìnima de crae",
    "User password history" : "Cronologia de is craes de s'utente",
    "Number of days until user password expires" : "Nùmeru de dies in antis de s'iscadèntzia de sa crae",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Nùmeru de tentativos de intrada in antis de su blocu de su contu (0 pro perunu lìmite)",
    "Forbid common passwords" : "Proibi is craes comunes",
    "Enforce upper and lower case characters" : "Pone caràteres a piticu e a mannu",
    "Enforce numeric characters" : "Pone caràtere numèricos",
    "Enforce special characters" : "Pone caràteres ispetziales",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Verìfica sa crae cun sa lista de craees cumprometidas de haveibeenpwnd.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Custu controllu creat unu hash de sa crae e imbiat is primu 5 caràteres de custu hash a is API de haveibeenpwned.com pro recuperare una lista de totu is hash chi cumintzant cun cussos caràteres. Luegu controllat si sa crae Nextcloud est presente in is resurtados.",
    "Unknown error" : "Errore disconnotu",
    "Minimal length has to be a non negative number" : "Sa longària mìnima depet èssere unu nùmeru positivu",
    "History size has to be a non negative number" : "Sa mannària de sa cronologia deper èssere unu nùmeru positivu",
    "Expiration days have to be a non negative number" : "Is dies de iscadèntzia depent èssere unu nùmeru positivu",
    "Maximum login attempts have to be a non negative number" : "Is tentativos de intrada màssimos depent èssere unu nùmeru positivu",
    "Password needs to be at least %s characters long" : "Sa crae depet èssere longa a su mancu %scaràteres ",
    "Minimal length" : "Longària mìnima",
    "days until user password expires" : "dies in antis de s'iscadèntzia de sa crae",
    "login attempts before the user account is blocked. (0 for no limit)" : "tentativos de intrada in antis de su blocu de su contu. (0 pro perunu lìmite)"
},
"nplurals=2; plural=(n != 1);");
